
#ifndef _C15_kl748_
#define _C15_kl748_

#ifdef __cplusplus
extern "C" {
#endif

extern void F71_968(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit748(void);

#ifdef __cplusplus
}
#endif

#endif
